@@ -55,7 +55,7 @@ function(x, title = NULL, description = NULL)
     # FUNCTION:
 
     # Convert Type:
-    if (class(x) == "fREG") x = residuals(x)
+    if (inherits(x, "fREG")) x = residuals(x)
     x = as.vector(x)
 
     # Call:
@@ -110,7 +110,7 @@ function(x, title = NULL, description = NULL)
     # FUNCTION:
 
     # Convert Type:
-    if (class(x) == "fREG") x = residuals(x)
+    if (inherits(x, "fREG")) x = residuals(x)
     x = as.vector(x)
 
     # Call:
@@ -161,7 +161,7 @@ function(x, title = NULL, description = NULL)
     DNAME = deparse(substitute(x))
 
     # Convert Type:
-    if (class(x) == "fREG") x = residuals(x)
+    if (inherits(x, "fREG")) x = residuals(x)
     x = as.vector(x)
 
     # Call:
@@ -393,7 +393,7 @@ function(x, title = NULL, description = NULL)
     DNAME = deparse(substitute(x))
 
     # Convert Type:
-    if (class(x) == "fREG") x = residuals(x)
+    if (inherits(x, "fREG")) x = residuals(x)
     x = as.vector(x)
 
     # Call:
@@ -450,7 +450,7 @@ function(x, method = c("sw", "jb"), na.rm = FALSE)
     # FUNCTION:
 
     # Convert Type:
-    if (class(x) == "fREG") x = residuals(x)
+    if (inherits(x, "fREG")) x = residuals(x)
     x = as.vector(x)
     if (na.rm) x = x[!is.na(x)]
 
@@ -517,7 +517,7 @@ function(x, title = NULL, description = NULL)
     DNAME = deparse(substitute(x))
 
     # Convert Type:
-    if (class(x) == "fREG") x = residuals(x)
+    if (inherits(x, "fREG")) x = residuals(x)
     x = as.vector(x)
 
     # Call:
@@ -613,7 +613,7 @@ function(x, title = NULL, description = NULL)
     DNAME = deparse(substitute(x))
 
     # Convert Type:
-    if (class(x) == "fREG") x = residuals(x)
+    if (inherits(x, "fREG")) x = residuals(x)
     x = as.vector(x)
 
     # Call:
@@ -699,7 +699,7 @@ function(x, title = NULL, description = NULL)
     DNAME = deparse(substitute(x))
 
     # Convert Type:
-    if (class(x) == "fREG") x = residuals(x)
+    if (inherits(x, "fREG")) x = residuals(x)
     x = as.vector(x)
 
     # Call:
@@ -806,7 +806,7 @@ function(x, title = NULL, description = NULL)
     DNAME = deparse(substitute(x))
 
     # Convert Type:
-    if (class(x) == "fREG") x = residuals(x)
+    if (inherits(x, "fREG")) x = residuals(x)
     x = as.vector(x)
 
     # Call:
@@ -889,7 +889,7 @@ function(x, title = NULL, description = NULL)
     DNAME = deparse(substitute(x))
 
     # Convert Type:
-    if (class(x) == "fREG") x = residuals(x)
+    if (inherits(x, "fREG")) x = residuals(x)
     x = as.vector(x)
 
     # Call:
@@ -1035,7 +1035,7 @@ function(x, title = NULL, description = NULL)
     call = match.call()
 
     # Convert Type:
-    if (class(x) == "fREG") x = residuals(x)
+    if (inherits(x, "fREG")) x = residuals(x)
     x = as.vector(x)
 
     # Test:
